@@ -4,4 +4,8 @@ use namespace::autoclean;
 
 extends 'Catalyst::View::Xslate';
 
-1;
\ No newline at end of file
+__PACKAGE__->config(
+  type => 'html',
+);
+
+1;
